/*
Replication Package
Step 1:
Generate variables at the physician level concerning assignment, test scores, and socioeconomic factors. 
Merge the starting date of the physicians. 
Save this dataset as "base_cohorte_rural_con_fecha_inicio."
 
*/



clear 		all
set 		more off

cap log close
log using "Logs/Data - Step 1.smcl", replace


	import 	excel using "Data\Anonimizada\Universidades_Top_Medicine.xlsx", sheet("Both") clear firstrow
	ren 	Id Id_Inst 
	ren 	Nombre ecaes_institution 
	replace ecaes_institution = upper(ecaes_institution)
	tempfile topu
	save 	`topu'

	import excel "Data\Anonimizada\instituciones acreditadas.xlsx", sheet("Sheet1") firstrow clear
	tempfile acred
	save    `acred', replace


	************************************************
	*    				Medicos					   *
	************************************************
	
	use 		"Data\Anonimizada\SSO_estimations_09092019", clear

	merge 		m:1 ecaes_institution using `topu'
	gen 		u_top = _merge==3
	drop 		_merge

	merge 		m:1 ecaes_institution using `acred', keep(1 3)
	gen 		u_acred = acreditado==1
	drop 		_merge

	ren 		treat_num_doc Documento 
	

	merge 		1:1 Documento draw_date using "Data\Anonimizada\Profesionales_Fecha_Inicio_Imp.dta", keep(1 3) gen(_mergeFI)
	label 		var _mergeFI "_merge Fecha Inicio"
	duplicates 	report if treat_cod_habi!=""

	* Creamos el codigo de hospital con 12 digitos
	gen 		codigo12 = substr(treat_cod_plaza,1,12)

	* Creamos el codigo de hospital con 10 digitos
	gen 		codigo10 = cond(length(substr(treat_cod_habi,1,10))==10,substr(treat_cod_habi,1,10),"0"+substr(treat_cod_habi,1,10))
	
	* Nota draw 2013-1 el codigo de plaza viene solo con 10 digitos, por tanto, para no perder información, se crea un identificador unicamente de 10 digitos
	* tener presente a la hora de parea
	* treat_cod_plaza es missing en 2013-1 por eso se usa treat_cod_habi
	 
	tempfile master
	save `master'

	************************************************
	*    		Codigos hospitales 2013-1		   *
	************************************************

	ren 		(draw_date draw_state treat_codmundep) (p_date p_state p_codmundep)
	keep 		p_codmundep codigo12 codigo10
	
	* Tomar no missings
	preserve
		keep if 	codigo12 != ""
		gduplicates drop
		tempfile 	nomissing
		save 		`nomissing'
	restore

	
	* Tomar missings
	keep if 	codigo12 == ""
	gduplicates drop codigo10 p_codmundep, force
	drop 		codigo12
	
	* Coincidencias unicas con la base de bebes
	preserve
		use 		mpio_nacimiento codigo12 fechanto using "Data\Anonimizada\1_VSR",replace
		gen 		p_codmundep=string(mpio_nacimiento)
		replace 	p_codmundep="0"+p_codmundep if length(p_codmundep)==4
		gen 		codigo10=substr(codigo12,1,10)
		gen 		bebes = 1
		gen 		year2013 = (year(fechanto) == 2013)
		collapse 	(sum) bebes, by(p_codmundep codigo10 codigo12 year2013)
		tempfile 	bebes
		save 		`bebes'
	restore

	merge 		1:m p_codmundep codigo10 using `bebes', keep(1 3) nogen
	duplicates 	tag p_codmundep codigo10, gen(dups1)
	duplicates 	tag p_codmundep codigo10 year2013, gen(dups2)
	gen 		cond1 =	(dups1 == 0 | (dups2 == 0 & year2013 == 1))
	replace 	cond1 = 0 if codigo12 == ""
	drop	 	bebes dups* year2013
	
	preserve
		keep if 	cond1 == 1
		tempfile 	matched1
		save 		`matched1'	
	restore	
		
	* Coincidencias unicas con si misma
	keep if		cond1 == 0
	drop 		codigo12 cond1
	gduplicates drop 
	merge 		1:m codigo10 p_codmundep using `nomissing', keep(1 3) nogen
	duplicates 	tag p_codmundep codigo10, gen(dups1)
	gen 		cond1 =	(dups1 == 0)
	replace 	cond1 = 0 if codigo12 == ""
	drop	 	dups1

	preserve
		keep if 	cond1 == 1
		replace 	cond1 = 2 if cond1 == 1
		tempfile 	matched2
		save 		`matched2'	
	restore	
	
	* Append
	use 		  	  `matched1', replace
	append 		using `matched2'
	rename 		p_codmundep treat_codmundep
	gsort 		codigo10 treat_codmundep -cond1
	duplicates 	drop codigo10 treat_codmundep, force
	tempfile 	codigos12
	save 		`codigos12'
	
	* Merge with physicians data
	use 		`master', replace
	merge 		m:1 codigo10 treat_codmundep using `codigos12', update keep(1 3 4) nogen
	drop if		codigo12 == ""
	bys 		codigo12: ereplace codigo10 = mode(codigo10) if codigo12 != ""
	
	
	************************************************
	*    			ECAES variables				   *
	************************************************
	*drop if		treat_year == 2013 & treat_month == 1
	drop 		ecaes_*

	global 		vars_ecaes ecaes_family_size ecaes_headhouse ecaes_dependants ecaes_educ* ///
				ecaes_ocup* ecaes_stratum ecaes_sisben ecaes_floor ecaes_cellphone /// 
				ecaes_internet ecaes_tv ecaes_wash ecaes_oven ecaes_car ecaes_room ///
				ecaes_famincome ecaes_stwrk ecaes_interperscore ecaes_probscore /// 
				ecaes_institution ecaes_microwave ecaes_fridge ecaes_marstatus /// 
				ecaes_single ecaes_instype ecaes_ocupfather ecaes_ocupmother ecaes_college_father ecaes_college_mother ecaes_pwork

			
	* Pegamos con base de Saber Pro para obtener el sexo del medico
	merge 		1:1 id draw_date using "Data\Anonimizada\Base_ps", keep(1 3) nogen keepusing(ecaes_gender ecaes_med_* ecaes_fin* $vars_ecaes)

	* conservamos solo los medicos (bacteriologos, enfermeras y odontologos no nos interesa, por ahora).
	keep 		if draw_bachelor==1


	* promedio de reading quantitative public health and health management
	egen 		prom_4 = rowmean(ecaes_med_reading ecaes_med_quantitative  ecaes_med_administracion ecaes_med_spublica) ///
				if ecaes_med_reading != . &  ecaes_med_quantitative != . & ecaes_med_administracion != . & ecaes_med_spublica != .

	label 		var prom_4 "Average of the 4 main tests: Reading, math, management and public health"

	drop 		if mi(prom_4)

	egen 		prom_acad 	= rowmean(ecaes_med_reading ecaes_med_quantitative)
	egen 		prom_health = rowmean(ecaes_med_administracion ecaes_med_spublica)

	***************************************************************
	*|||||||||||||||||||| PRINCIPAL COMPONENT ||||||||||||||||||||* 
	***************************************************************
	pca 		ecaes_med_reading ecaes_med_quantitative  ecaes_med_administracion ecaes_med_spublica, com(1)
	predict 	comp1 

	pca 		ecaes_med_reading ecaes_med_quantitative, com(1)  
	predict  	comp1_acad

	pca 		ecaes_med_administracion ecaes_med_spublica, com(1)
	predict 	comp1_health

	* Dejamos unicamente las personas que fueron tratados
	keep 		if treat_rural == 1

	************************************************
	*    			Imputacion fechas			   *
	************************************************
	
	replace 	distancia_imp = 0 if distancia_imp<0

	/*Criterio 1: Imputar la fecha de inicio de la misma profesión, hospital y 
	cohorte de sorteo */
	sort codigo10 codigo12 draw_date 
	egen d1=mean(distancia_imp), by(codigo10 codigo12 draw_date)
	
	replace distancia_imp=d1 if distancia_imp==.

	/*Criterio 3: Imputar la fecha de inicio de la misma profesión y hospital*/	
	sort codigo10 codigo12 draw_date
	egen d3=mean(distancia_imp), by(codigo10 codigo12)
	
	replace distancia_imp=d3 if distancia_imp==.
	
	/*Criterio 4: Imputar la fecha de inicio de la misma profesión, sorteo y 
	departamento */
	egen d4=mean(distancia_imp), by(draw_date depto)
	
	replace distancia_imp=d4 if distancia_imp==.	
	
	************************************************
	*    		Variables and labels			   *
	************************************************
	
	gen 		n_docs_temp 		= 1 
	gen 		n_docs_women_temp 	= ecaes_gender==1
	gen 		n_docs_men_temp 	= ecaes_gender==0
	ren 		u_top n_docs_top_temp

	gen 		n_docs_top_income_temp = ecaes_famincome>=4
	tab 		ecaes_famincome n_docs_top_income_temp

	gen n_docs_father_temp =  	ecaes_college_father ==1
	gen n_docs_mother_temp = 	ecaes_college_mother ==1
	gen n_docs_work_temp =  		ecaes_pwork ==1
		

	ren 		ecaes_instype n_docs_u_publica_temp
	ren 		u_acred n_docs_u_acred_temp 
	global 		vars n_docs_temp n_docs_women_temp n_docs_men_temp n_docs_top_temp n_docs_top_income_temp n_docs_u_publica_temp n_docs_u_acred_temp n_docs_father_temp n_docs_mother_temp n_docs_work_temp
	
	* Descriptive score variables
	foreach 	x in $vars {
		egen 	`x'_a = total(`x'), by(codigo10 codigo12 draw_date treat_codmundep)
		drop 	`x'
	}
	ren 	*_temp_a *

	foreach x in prom_4 prom_acad prom_health comp1 comp1_acad comp1_health ecaes_med_reading ecaes_med_quantitative ecaes_med_administracion ecaes_med_spublica {
		egen 		ave_`x' = mean(`x')  , 			by(codigo10 codigo12 draw_date treat_codmundep)
		egen 		p25_`x' = pctile(`x'), p(25) 	by(codigo10 codigo12 draw_date treat_codmundep)
		egen 		p50_`x' = pctile(`x'), p(50) 	by(codigo10 codigo12 draw_date treat_codmundep)
		egen 		p75_`x' = pctile(`x'), p(75) 	by(codigo10 codigo12 draw_date treat_codmundep)
		egen 		min_`x' = min(`x'), 			by(codigo10 codigo12 draw_date treat_codmundep)
		egen 		max_`x' = max(`x'), 			by(codigo10 codigo12 draw_date treat_codmundep)
	}

	egen ave_program = median(prom_health), by(draw_date ecaes_institution Profesion)
		
	* Labels and order
	label 		var ave_prom_4 	"Average score of the cohort (hospital-draw level)"
	label 		var p25_prom_4 	"Percentile 25 score of the cohort (hospital-draw level)"
	label 		var p50_prom_4 	"Percentile 25 score of the cohort (hospital-draw level)"
	label 		var p75_prom_4 	"Percentile 25 score of the cohort (hospital-draw level)"
	label 		var treat_year 	"draw year"
	label 		var treat_month "draw month"
	label 		var Documento 	"treat id"
	label 		var codigo12 	"12 digits hospital code"
 
	compress
	order 		Documento codigo12 codigo10 treat_year treat_month treat_codmundep 

	* Days between draw date and start
	egen 		tag_cohorte = tag(draw_date draw_state codigo10 codigo12)

	sum 		distancia_imp if tag_cohorte==1, d
	
	egen 		ave_distancia_imp_hc = mean(distancia_imp), by(draw_date draw_state codigo10 codigo12)
	egen 		ave_distancia_imp_c  = mean(distancia_imp), by(draw_date draw_state)
	egen 		ave_distancia_imp_d  = mean(distancia_imp), by(draw_date)

	* Labels
	label 		var ave_distancia_imp_hc "promedio de la distancia draw-inicio por hospital-cohorte"
	label 		var ave_distancia_imp_c  "promedio de la distancia draw-inicio por draw-state"
	label 		var ave_distancia_imp_d  "promedio de la distancia draw-inicio por draw"

	* Draw day imputation
	replace    	draw_day= mdy(1,25,2013)  if draw_date==ym(2013,1) & mi(draw_day)
	replace 	draw_day= mdy(4,19,2013)  if draw_date==ym(2013,4) & mi(draw_day)
	replace 	draw_day= mdy(7,19,2013)  if draw_date==ym(2013,7) & mi(draw_day)
	replace 	draw_day= mdy(10,18,2013) if draw_date==ym(2013,10) & mi(draw_day)
	replace 	draw_day= mdy(1,17,2014)  if draw_date==ym(2014,1) & mi(draw_day)
	replace 	draw_day= mdy(4,22,2014)  if draw_date==ym(2014,4) & mi(draw_day)
	replace 	draw_day= mdy(7,22,2014)  if draw_date==ym(2014,7) & mi(draw_day)
	replace 	draw_day= mdy(10,22,2014) if draw_date==ym(2014,10) & mi(draw_day)
	format  	draw_day %td
	
	* Start using Rule if thumb
	sum 		distancia_imp
	gen 		p_fechin_obs_thumb = draw_day+int(`r(mean)')
	gen 		p_fechfi_obs_thumb = p_fechin_obs_thumb+365

	keep 		codigo12 codigo10 draw_date draw_state treat_codmundep *prom* *n_docs* *comp1* ave_dist*  draw_day p_fech* *_ecaes_med_* ave_program
	drop 		prom_4 prom_acad prom_health comp1 comp1_acad comp1_health 

	* Collapse at cohort level
	collapse (max) ave_program, by(codigo12 codigo10 draw_date draw_state treat_codmundep *prom* *n_docs* *comp1* ave_dist* draw_day p_fech* *_ecaes_med_*)

	ren 		(draw_date draw_state treat_codmundep) (p_date p_state p_codmundep)
	compress 

	foreach x in ave {
		gen 		p_fechin_obs_`x' = draw_day+`x'_distancia_imp_hc
		gen			p_fechfi_obs_`x' = p_fechin_obs_`x'+365
	}

	format 		p_date %tm
	format 		p_fechin_obs_ave %td
	format 		p_fechfi_obs_ave %td

	gen 		percent_female 		= n_docs_women/n_docs
	gen 		percent_top 		= n_docs_top/n_docs 
	gen 		percent_top_income 	= n_docs_top_income/n_docs
	gen 		percent_public 		= n_docs_u_publica/n_docs
	gen 		percent_acred 		= n_docs_u_acred/n_docs	
	gen 		percent_father 		= n_docs_father/n_docs	
	gen 		percent_mother 		= n_docs_mother/n_docs	
	gen 		percent_work 		= n_docs_work/n_docs	

	save 		"Data\base_cohorte_rural_con_fecha_inicio.dta", replace 
	log close