	/*
	
	Replication package
	Table 2 - Balancing hospitals
	
	*/

    
clear 		all 
set 		more off

cap log close
log using "Logs/Table 2.smcl", replace
	
	
********************************************************************************

	use 	        "Data/Anonimizada/base_medico_rural_con_fecha_inicio",replace
    
	cap drop        p_date
	gen             p_date =ym(p_year,p_month)
	format          p_date %tm
	drop 	        codigo10

	preserve
    
        use         "Data/base_hospital_cohorte_bebe", replace
        keep if     p_emb_n4_obs==1 & d_area_metro==0
        tempfile    base1
        save        `base1', replace 
        
	restore

	joinby  codigo12 p_date using `base1', unm(b) _merge(merge_pru) 
	keep 	if p_emb_n4_obs==1 & d_area_metro==0
	ren 	codigo12 codigo	
	
	

	gsort                   p_num_doc p_date codigo -id_nacido	
	duplicates drop         p_num_doc p_date codigo, force 
	drop 	                p_mes_inicio
	gen 	                p_mes_inicio=ym(2010,1)
	merge m:1               p_mes_inicio codigo using "Data/Anonimizada/SSO_Hospital_Vitales.dta", keep(3) nogen
		


	*First cohort
	egen	min_date = min(p_date), by(codigo)
    gen     ave_prom_health_first_prov = ave_prom_health if p_date == min_date
    egen    ave_prom_health_first = mean(ave_prom_health_first_prov), by(codigo)
	drop 	min_date
	
	egen	min_date = min(p_date), by(codigo)
    gen     prom_4_first_prov = prom_4 if p_date == min_date
    egen    prom_4_first = mean(prom_4_first_prov), by(codigo)
	drop 	min_date
	

	global 	covars  h_prop_unhealthy h_prop_low_weight h_prop_v_nacer_38_41 	///
					h_prop_v_apgar1_masy7  h_prop_numconsul4      				/// 
                    h_prop_babyfemale h_prop_basicedu h_prop_married 			///
					h_prop_adolescent tot_hosp c_population

					
	/* Table */
	
	global 	S: word count $covars
		
	mat vlrp_b1 = J($S ,2,.)

	local c = 1
	foreach var of global covars{
		
		reghdfe `var' ave_prom_health_first, abs(p_state p_cohorte) cluster(codigo) 

		mat vlrp_b1[`c',1] = _b[ave_prom_health_first] 
		mat vlrp_b1[`c',2] = _se[ave_prom_health_first]
        
		local c = `c'+1	
        
	}
		
	mat rown vlrp_b1 = $covars
	mat list vlrp_b1
	
	putexcel set "Results/Tables paper matrices replication.xls", sheet("Raw Table 2") modify
	putexcel B2=mat(vlrp_b1)
	
	/* Table */
	
	global 	S: word count $covars
		
	mat vlrp_b1 = J($S ,2,.)

	local c = 1
	foreach var of global covars{
		
		reghdfe `var' prom_4_first, abs(p_state p_cohorte) cluster(codigo) 

		mat vlrp_b1[`c',1] = _b[prom_4_first] 
		mat vlrp_b1[`c',2] = _se[prom_4_first]
        
		local c = `c'+1	
        
	}
		
	mat rown vlrp_b1 = $covars
	mat list vlrp_b1
	
	putexcel set "Results\Tables paper matrices replication.xls", sheet("Raw Table A2") modify
	putexcel B2=mat(vlrp_b1)
	
    
	
********************************************************************************

	use 	        "Data/Anonimizada/base_medico_rural_con_fecha_inicio",replace
    
	cap drop        p_date
	gen             p_date =ym(p_year,p_month)
	format          p_date %tm
	drop 	        codigo10

	preserve
    
        use         "Data/base_hospital_cohorte_bebe", replace
		keep if     p_emb_obs_ave==1 & d_area_metro==0 
        tempfile    base1
        save        `base1', replace 
        
	restore

	joinby  codigo12 p_date using `base1', unm(b) _merge(merge_pru) 
	keep 	if p_emb_obs_ave==1 & d_area_metro==0
	ren 	codigo12 codigo	
	
	

	gsort                   p_num_doc p_date codigo -id_nacido	
	duplicates drop         p_num_doc p_date codigo, force 
	merge m:1               p_mes_inicio codigo using "Data/Anonimizada/SSO_Hospital_Vitales.dta", keep(3) nogen
		


	*First cohort
	egen	min_date = min(p_date), by(codigo)
    gen     ave_prom_health_first_prov = ave_prom_health if p_date == min_date
    egen    ave_prom_health_first = mean(ave_prom_health_first_prov), by(codigo)
	drop 	min_date
	
	egen	min_date = min(p_date), by(codigo)
    gen     prom_4_first_prov = prom_4 if p_date == min_date
    egen    prom_4_first = mean(prom_4_first_prov), by(codigo)
	drop 	min_date
	

	global 	covars  h_prop_babyfemale h_prop_basicedu h_prop_married 			///
					h_prop_adolescent tot_hosp c_population
	
	/* Table */
	
	global 	S: word count $covars
		
	mat vlrp_b1 = J($S ,2,.)

	local c = 1
	foreach var of global covars{
		
		reghdfe `var' ave_prom_health_first, abs(p_state p_cohorte) cluster(codigo) 

		mat vlrp_b1[`c',1] = _b[ave_prom_health_first] 
		mat vlrp_b1[`c',2] = _se[ave_prom_health_first]
        
		local c = `c'+1	
        
	}
		
	mat rown vlrp_b1 = $covars
	mat list vlrp_b1
	
	putexcel set "Results\Tables paper matrices replication.xls", sheet("Raw Table 2") modify
	putexcel B14=mat(vlrp_b1)
	
	/* Table */
	
	global 	S: word count $covars
		
	mat vlrp_b1 = J($S ,2,.)

	local c = 1
	foreach var of global covars{
		
		reghdfe `var' prom_4_first, abs(p_state p_cohorte) cluster(codigo) 

		mat vlrp_b1[`c',1] = _b[prom_4_first] 
		mat vlrp_b1[`c',2] = _se[prom_4_first]
        
		local c = `c'+1	
        
	}
		
	mat rown vlrp_b1 = $covars
	mat list vlrp_b1
	
	putexcel set "Results\Tables paper matrices replication.xls", sheet("Raw Table A2") modify
	putexcel B14=mat(vlrp_b1)
	
	
log close