	/*
	
	Replication package
	Table 5. Heterogenenity of the effects across mother's characteristics
	Table A.7. Other heterogeneous effects
	Last modified: 02/10/2023 
	
	*/
	
clear 		all 
set 		more off


cap log close
log using "Logs/Table 5 - Table 6.smcl", replace	
	
********************************************************************************
	
	* Heterogeneous effect of mothers and newborns
	use 		"Data\base_hospital_cohorte_bebe", replace
		
	keep 		if p_emb_obs_ave==1 
	keep        if d_area_metro ==0
	
	gen edumadre=(nivel_madre<=3 | nivel_madre==13)

	pca 	ave_ecaes_med_administracion ave_ecaes_med_spublica, com(1)
	predict comp1_health
	 
	
	*Creating hospital covars (3 years before) baby level
	egen p75_unhealthy = pctile(h_prop_unhealthy), p(75)
	gen dummy_unhealthy = (h_prop_unhealthy > p75_unhealthy & h_prop_unhealthy!=.)
	drop p75_unhealthy h_prop_unhealthy	
	
	
	*Creating hospital covars (3 years before) hospital level
	/*
	preserve
	
		collapse (mean) h_prop_unhealthy, by(codigo12)
		egen p75_unhealthy = pctile(h_prop_unhealthy), p(50)
		gen dummy_unhealthy = (h_prop_unhealthy > p75_unhealthy & h_prop_unhealthy!=.)
		drop p75_unhealthy h_prop_unhealthy
		
		tempfile dummy
		save `dummy'
	
	restore
	
	merge m:1 codigo12 using `dummy', nogen
	*/
	
	*Creating hospital covars (3 years before) old version
	/*
	egen tag               =  tag(codigo12)		
	egen p75_bw            =  pctile(h_prop_low_weight)   if tag==1, p(75)
	egen p75_bw1		   =  max(p75_bw)
	egen p75_prem          =  pctile(h_prop_v_nacer_38_41) if tag==1,p(75)
	egen p75_prem1		   =  max(p75_prem)
	egen p75_unhealthy     =  pctile(h_prop_unhealthy)   if tag==1, p(75)
	egen p75_unhealthy1	   =  max(p75_unhealthy)
	egen p75_apgar         =  pctile(h_prop_apgar1_mas7) if tag==1,p(75)
	egen p75_apgar1		   =  max(p75_apgar)

	gen dummy_prematurotop  = (h_prop_v_nacer_38_41<p75_prem1  & h_prop_v_nacer_38_41!=.)
	gen dummy_bwtop         = (h_prop_low_weight   >p75_bw1    & h_prop_low_weight!=.)
	gen dummy_unhealthy     = (h_prop_unhealthy   >p75_unhealthy1    & h_prop_unhealthy!=.)
	gen dummy_apgartop      = (h_prop_apgar1_mas7>p75_apgar1 & h_prop_apgar1_mas7!=.)

	drop p75_*
	*/
	
	gen  dummy_1hosp = (tot_hosp==1)
	gen  apgar1menor7 = apgar1min_7==0
	egen codigo_tot= group(codigo12 codigo10)	
	
		
	global 		c_b      babyfemale adolescent basicedu married 
	global 		c_m      pop100 dummy_1hosp i.area 
	global		c_cd     dummy_female 
	global      c_h      dummy_bwtop dummy_prematurotop dummy_apgartop
	global      outcomes bpn nacer_menos_37 apgar1menor7
	
	

	gen 	days_coinc=min(p_fechfi_obs_ave,fechanto)-max(v_fconcep,p_fechin_obs_ave)+1
	gen 	w_doc=round(days_coinc)*n_docs
	egen 	id_h=group(codigo12)
    	
    egen 	p_drawm=min(p_draw),by(id_nacido)
    gen     ave_prom_health_first_prov = ave_prom_health if p_drawm == p_draw
    egen    ave_prom_health_first = mean(ave_prom_health_first_prov), by(id_nacido)
    
    gen 	full=p_fechfi_obs_ave>=fechanto & v_fconcep>=p_fechin_obs_ave
	egen 	Full=max(full),by(id_nacido)
	replace w_doc=0 if full==0 & Full==1
    
	collapse (mean) ave_prom_4 comp1_health ave_comp1 ave_prom_health ave_ecaes_med_administracion ave_ecaes_med_spublica ave_ecaes_med_reading ave_ecaes_med_quantitative (max) full dummy_female dummy_top dummy_public [fw=w_doc],by($c_b pop100 p_drawm edumadre dummy_1hosp area $outcomes dummy_unhealthy embarazos_madre d_area_metro id_nacido id_h year codigo_tot ave_prom_health_first tipo_parto)
		
	/* Table */
	
	egen 	tagc=tag(p_drawm codigo_tot)
	sum     ave_ecaes_med_administracion if tagc==1
	replace ave_ecaes_med_administracion=(ave_ecaes_med_administracion-r(mean))/r(sd)
	sum     ave_ecaes_med_spublica if tagc==1
	replace ave_ecaes_med_spublica=(ave_ecaes_med_spublica-r(mean))/r(sd)
	sum     ave_prom_health if tagc==1
	replace ave_prom_health=(ave_prom_health-r(mean))/r(sd)
	sum     comp1_health if tagc==1
	replace comp1_health=(comp1_health-r(mean))/r(sd)
	sum     ave_prom_4 if tagc==1
	replace ave_prom_4=(ave_prom_4-r(mean))/r(sd)
    
    sum     ave_prom_health_first if tagc == 1
    replace ave_prom_health_first=(ave_prom_health_first-r(mean))/r(sd)
	
	gen 	unhealthy=1-(bpn==0&nacer_menos_37==0&apgar1menor7==0)
    gen     first_time = (embarazos_madre==1)
    gen     cesarea    = (tipo_parto == 2)
    
    
	
	foreach var in unhealthy  {
        
        mat 	table1 = J(6,2,.)
        
		local c=1
		foreach condi in babyfemale 	{
		di in red "*** `condi' ***"        
		
		foreach x in ave_prom_health    {

			di in red "*** `condi'==1 ***"			
			
			ivreghdfe `var' (`x' = `x'_first) if `condi'==1 , abs(p_drawm) cluster(id_h)
			mat 	table1[1,`c']  = _b[`x']
			mat 	table1[2 ,`c'] = _se[`x']
			
			mat table1[5,`c'] = e(N) // obs
							
			sum `var' if e(sample)==1
			mat table1[4,`c']  = r(mean)
			mat table1[3,`c'] = table1[1,`c']/table1[4,`c']
			
			local n1 = e(N)
			
			
			di in red "*** `condi'==0 ***"
				
			ivreghdfe `var' (`x' = `x'_first) if `condi'==0 , abs(p_drawm) cluster(id_h)   
			mat 	table1[1,`c'+1]  = _b[`x']
			mat 	table1[2 ,`c'+1] = _se[`x']
				
			mat table1[5,`c'+1] = e(N) // obs
							
			sum `var'  if e(sample)==1
			mat table1[4,`c'+1]  = r(mean)
			mat table1[3,`c'+1] = table1[1,`c'+1]/table1[4,`c'+1]
			
			local n2 = e(N)

			
			* Welch test
			local v = ((table1[2,`c']^2) + (table1[2,`c'+1]^2))^2 / (((table1[2,`c']^4)*(1/(`n1'-1))) + ((table1[2,`c'+1]^4)*(1/(`n2'-1))))
			mat table1[6,`c'] = 2*ttail(`v',abs((table1[1,`c']-table1[1,`c'+1])/(sqrt((table1[2,`c']^2) + (table1[2,`c'+1]^2)))))
			
			
			local c= `c'+2

            
			}
			
		}
		
	}
	
	mat lis table1
	putexcel set "Results\Tables paper matrices replication.xls", sheet("Raw Table 6") modify
	putexcel B2=mat(table1)
	
	
	foreach var in unhealthy  {
	
		mat 	table1 = J(6,8,.)
	
		local c=1
		foreach condi in first_time adolescent edumadre married 	{
		di in red "*** `condi' ***"
		
		foreach x in ave_prom_health   {
		
			di in red "*** `condi'==1 ***"			
			
			ivreghdfe `var' (`x' = `x'_first) if `condi'==1 , abs(p_drawm) cluster(id_h)
			mat 	table1[1,`c']  = _b[`x']
			mat 	table1[2 ,`c'] = _se[`x']
			
			mat table1[5,`c'] = e(N) // obs
							
			sum `var' if e(sample)==1
			mat table1[4,`c']  = r(mean)
			mat table1[3,`c'] = table1[1,`c']/table1[4,`c']
			
			local n1 = e(N)
			
			
			di in red "*** `condi'==0 ***"
				
			ivreghdfe `var' (`x' = `x'_first) if `condi'==0 , abs(p_drawm) cluster(id_h)   
			mat 	table1[1,`c'+1]  = _b[`x']
			mat 	table1[2 ,`c'+1] = _se[`x']
				
			mat table1[5,`c'+1] = e(N) // obs
							
			sum `var'  if e(sample)==1
			mat table1[4,`c'+1]  = r(mean)
			mat table1[3,`c'+1] = table1[1,`c'+1]/table1[4,`c'+1]
			
			local n2 = e(N)

			
			* Welch test
			local v = ((table1[2,`c']^2) + (table1[2,`c'+1]^2))^2 / (((table1[2,`c']^4)*(1/(`n1'-1))) + ((table1[2,`c'+1]^4)*(1/(`n2'-1))))
			mat table1[6,`c'] = 2*ttail(`v',abs((table1[1,`c']-table1[1,`c'+1])/(sqrt((table1[2,`c']^2) + (table1[2,`c'+1]^2)))))
			
			
			local c= `c'+2
		
			}
		
		}
		
	}	
	
	mat lis table1
	putexcel set "Results\Tables paper matrices replication.xls", sheet("Raw Table 5") modify
	putexcel B2=mat(table1)
		

********************************************************************************

	* Heterogeneous effects by share of physicians
	use 		"Data/base_hospital_cohorte_bebe", replace

	*Usando como denominador el numero de medicos de la ciudad en 2012
	cap drop _merge 
	merge m:1 codmundep using "Data\Anonimizada\Weights_2012.dta", keep(1 3)
	drop _merge

	keep 		if p_emb_obs_ave==1 
	keep        if d_area_metro ==0


	pca 	ave_ecaes_med_administracion ave_ecaes_med_spublica, com(1)
	predict comp1_health	
	 
	cap drop tag median_bw median_bweight median_prem median_prematuro dummy_prematuro dummy_bw p75_bw p75_bweight p75_prem p75_prematuro dummy_prematuro75 dummy_bw75


	*Creating hospital covars (bw and prematurity 3 years before)
	egen tag               =  tag(codigo10 codigo12)		
	egen p75_bw            =  pctile(h_prop_low_weight)   if tag==1, p(75)
	egen p75_bw1		   =  max(p75_bw)
	egen p75_prem          =  pctile(h_prop_v_nacer_38_41) if tag==1,p(75)
	egen p75_prem1		   =  max(p75_prem)
	egen p75_apgar         =  pctile(h_prop_apgar1_mas7) if tag==1,p(75)
	egen p75_apgar1		   =  max(p75_apgar)
	
	gen dummy_prematurotop  = (h_prop_v_nacer_38_41<p75_prem1  & h_prop_v_nacer_38_41!=.)
	gen dummy_bwtop         = (h_prop_low_weight>p75_bw1 & h_prop_low_weight!=.)
	gen dummy_apgartop      = (h_prop_apgar1_mas7>p75_apgar1 & h_prop_apgar1_mas7!=.)

	drop p75_*
	
	gen  dummy_1hosp = (tot_hosp==1)
	gen  apgar1menor7 = apgar1min_7==0
	egen codigo_tot= group(codigo12 codigo10)	
	
	sum pop100, det
	
	gen pop=(pop100>=r(p50))
	
		
	global 		c_b      babyfemale adolescent basicedu married 
	global 		c_m      pop100 dummy_1hosp i.area 
	global		c_cd     dummy_female 
	global      c_h      dummy_bwtop dummy_prematurotop dummy_apgartop
	global      outcomes bpn nacer_menos_37 apgar1menor7

	* Crear base con una sola observacion por bebe 
	gen 	days_coinc=min(p_fechfi_obs_ave,fechanto)-max(v_fconcep,p_fechin_obs_ave)+1
	gen 	w_docinic=round(days_coinc)*n_docs
	gen 	w_doc=round(days_coinc)*n_docs
	egen 	id_h=group(codigo12)
	tab 	p_draw
	
    egen 	p_drawm=min(p_draw),by(id_nacido)
    gen     ave_prom_health_first_prov = ave_prom_health if p_drawm == p_draw
    egen    ave_prom_health_first = mean(ave_prom_health_first_prov), by(id_nacido)
	
	* weights
	egen Total_physic=rowmean(medico_*)
	bys id_nacido: egen physic_cohorte=total(n_docs)
	bys id_nacido: egen min_date_sso=min(p_fechin_obs_ave)
	bys id_nacido: egen max_date_sso=max(p_fechfi_obs_ave)
	format min_date_sso max_date_sso %td
	gen exposicion=min(max_date_sso,fechanto)-max(v_fconcep,min_date_sso)
	gen dias_gestacion=semanas_gestacion*7

	
	* Ponderador a nivel cohorte
	preserve
	
		collapse (sum) physic_cohorte Total_physic, by(codmundep)
		gen ponderador=physic_cohorte/(Total_physic+physic_cohorte)
		replace ponderador = round(ponderador*100)
		drop if ponderador == .
	
		egen m_ponderador = pctile(ponderador), p(75)
		gen m_ponderador75 = (ponderador > m_ponderador & ponderador!=.)

		keep codmundep m_ponderador75 ponderador
	
		tempfile ponderador
		save `ponderador'
	
	restore
	
	collapse (mean) ave_prom_4 comp1_health ave_comp1 ave_prom_health ave_ecaes_med_administracion ave_ecaes_med_spublica ave_ecaes_med_reading ave_ecaes_med_quantitative (max) exposicion dias_gestacion physic_cohorte dummy_female dummy_top dummy_public Total_physic (sum) n_docs [fw=w_doc],by($c_b pop100 p_drawm dummy_1hosp area $c_h $outcomes embarazos_madre d_area_metro id_nacido id_h year codigo_tot ave_prom_health_first codmundep)

	
	/* Conteo hospitales municipio
	preserve
		keep id_h codmundep
		duplicates drop
		duplicates tag codmundep, gen(dups)
		drop if dups > 0
		drop dups id_h
		
		tempfile munics
		save  `munics'
	restore
	
	* Mantenemos los municipios con un solo hospital
	merge m:1 codmundep using `munics', keep(3)	nogen
	*/
	
	merge m:1 codmundep using `ponderador' , keep(3) nogen
	*drop m_ponderador75
	*egen m_ponderador = pctile(ponderador), p(75)
	*gen m_ponderador75 = (ponderador > m_ponderador & ponderador!=.)	
	

	/* Table */

	global p_res "d_area_metro==0"
	global res1  $c_b $c_m $c_cd $c_h    if         $p_res , abs(p_drawm) cluster(id_h)
	global res2  				     if s1==1 & $p_res , abs(p_drawm) cluster(id_h)

	*Estandarizar los puntajes
	egen 	tagc=tag(p_drawm codigo_tot)
	sum     ave_ecaes_med_administracion if tagc==1 & $p_res
	replace ave_ecaes_med_administracion=(ave_ecaes_med_administracion-r(mean))/r(sd)
	sum     ave_ecaes_med_spublica if tagc==1 & $p_res
	replace ave_ecaes_med_spublica=(ave_ecaes_med_spublica-r(mean))/r(sd)
	sum     ave_prom_health if tagc==1 & $p_res
	replace ave_prom_health=(ave_prom_health-r(mean))/r(sd)
	sum     ave_prom_4 if tagc==1 & $p_res
	replace ave_prom_4=(ave_prom_4-r(mean))/r(sd)
	sum     comp1_health if tagc==1 & $p_res
	replace comp1_health=(comp1_health-r(mean))/r(sd)

    sum     ave_prom_health_first if tagc == 1
    replace ave_prom_health_first=(ave_prom_health_first-r(mean))/r(sd)

	gen 	unhealthy=1-(bpn==0&nacer_menos_37==0&apgar1menor7==0)

	gen 	s1=0

	mat 	table1 = J(6,2,.)

	local c=1
	foreach condi in m_ponderador75  {
				
	foreach var in unhealthy {
			
		di in red "*** `condi' ***"
		
		foreach x in ave_prom_health    {

			di in red "*** `condi'==1 ***"			
			
			ivreghdfe `var' (`x' = `x'_first) if `condi'==1 , abs(p_drawm) cluster(id_h)
			mat 	table1[1,`c']  = _b[`x']
			mat 	table1[2 ,`c'] = _se[`x']
			
			mat table1[5,`c'] = e(N) // obs
							
			sum `var' if e(sample)==1
			mat table1[4,`c']  = r(mean)
			mat table1[3,`c'] = table1[1,`c']/table1[4,`c']
			
			local n1 = e(N)
			
			
			di in red "*** `condi'==0 ***"
				
			ivreghdfe `var' (`x' = `x'_first) if `condi'==0 , abs(p_drawm) cluster(id_h)   
			mat 	table1[1,`c'+1]  = _b[`x']
			mat 	table1[2 ,`c'+1] = _se[`x']
				
			mat table1[5,`c'+1] = e(N) // obs
							
			sum `var'  if e(sample)==1
			mat table1[4,`c'+1]  = r(mean)
			mat table1[3,`c'+1] = table1[1,`c'+1]/table1[4,`c'+1]
			
			local n2 = e(N)

			
			* Welch test
			local v = ((table1[2,`c']^2) + (table1[2,`c'+1]^2))^2 / (((table1[2,`c']^4)*(1/(`n1'-1))) + ((table1[2,`c'+1]^4)*(1/(`n2'-1))))
			mat table1[6,`c'] = 2*ttail(`v',abs((table1[1,`c']-table1[1,`c'+1])/(sqrt((table1[2,`c']^2) + (table1[2,`c'+1]^2)))))
			
			
			local c= `c'+2
            
			}
	
		}
	
	}

	mat lis table1
	putexcel set "Results\Tables paper matrices replication.xls", sheet("Raw Table 6") modify
	putexcel D2=mat(table1)
	
	
	 /* Figures set 2 */
/*	 
    global labels ""Low share of SSO physicians" "High share of SSO physicians""

    local o = 1
    foreach label in $labels {
            
        global o`o' = "`label'"	
        local o = `o' + 1
        
    }
	
   local i = 1
    foreach condi in m_ponderador75 {
         
        binscatterhist 	unhealthy ave_prom_health_first if `condi' == 1 , n(100) absorb(p_drawm)                  ///
						ytitle(${o`i'}) xtitle("Average Health Scores")                   	///
						m(circle_hollow) mc(black) lc(red)                                  ///
						coefficient(0.0001) stars(nostars) msize(small) boxposition(`pos') 	///
						replace name(fig`i') cluster(id_h)
         
        local i = `i' + 1 
		
        binscatterhist 	unhealthy ave_prom_health_first if `condi' == 0 , n(100) absorb(p_drawm)                  ///
						ytitle(${o`i'}) xtitle("Average Health Scores")                   	///
						m(circle_hollow) mc(black) lc(red)                                  ///
						coefficient(0.0001) stars(nostars) msize(small) boxposition(`pos') 	///
						replace name(fig`i') cluster(id_h)
         
        local i = `i' + 1 
        
    }

	graph combine fig1 fig2 , graphregion(fcolor(white) style(none) color(white)) r(1) xcom ycom
	graph export "Results\New results\\het_binned_set.png", width(4800) height(1600) replace
	graph drop _all	
*/
	
log close		
		